==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/webpubsub/kotlin/WebPubSubSharedPrivateLinkResourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.webpubsub.kotlin

import com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResourceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes a Shared Private Link Resource
 * Azure REST API version: 2023-02-01. Prior API version in Azure Native 1.x: 2021-04-01-preview.
 * Other available API versions: 2023-03-01-preview, 2023-06-01-preview, 2023-08-01-preview.
 * ## Example Usage
 * ### WebPubSubSharedPrivateLinkResources_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var webPubSubSharedPrivateLinkResource = new AzureNative.WebPubSub.WebPubSubSharedPrivateLinkResource("webPubSubSharedPrivateLinkResource", new()
 *     {
 *         GroupId = "sites",
 *         PrivateLinkResourceId = "/subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/myResourceGroup/providers/Microsoft.Web/sites/myWebApp",
 *         RequestMessage = "Please approve",
 *         ResourceGroupName = "myResourceGroup",
 *         ResourceName = "myWebPubSubService",
 *         SharedPrivateLinkResourceName = "upstream",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/webpubsub/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := webpubsub.NewWebPubSubSharedPrivateLinkResource(ctx, "webPubSubSharedPrivateLinkResource", &webpubsub.WebPubSubSharedPrivateLinkResourceArgs{
 * 			GroupId:                       pulumi.String("sites"),
 * 			PrivateLinkResourceId:         pulumi.String("/subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/myResourceGroup/providers/Microsoft.Web/sites/myWebApp"),
 * 			RequestMessage:                pulumi.String("Please approve"),
 * 			ResourceGroupName:             pulumi.String("myResourceGroup"),
 * 			ResourceName:                  pulumi.String("myWebPubSubService"),
 * 			SharedPrivateLinkResourceName: pulumi.String("upstream"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResource;
 * import com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResourceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var webPubSubSharedPrivateLinkResource = new WebPubSubSharedPrivateLinkResource("webPubSubSharedPrivateLinkResource", WebPubSubSharedPrivateLinkResourceArgs.builder()
 *             .groupId("sites")
 *             .privateLinkResourceId("/subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/myResourceGroup/providers/Microsoft.Web/sites/myWebApp")
 *             .requestMessage("Please approve")
 *             .resourceGroupName("myResourceGroup")
 *             .resourceName("myWebPubSubService")
 *             .sharedPrivateLinkResourceName("upstream")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:webpubsub:WebPubSubSharedPrivateLinkResource upstream /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.SignalRService/webPubSub/{resourceName}/sharedPrivateLinkResources/{sharedPrivateLinkResourceName}
 * ```
 * @property groupId The group id from the provider of resource the shared private link resource is for
 * @property privateLinkResourceId The resource id of the resource the shared private link resource is for
 * @property requestMessage The request message for requesting approval of the shared private link resource
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property resourceName The name of the resource.
 * @property sharedPrivateLinkResourceName The name of the shared private link resource
 */
public data class WebPubSubSharedPrivateLinkResourceArgs(
    public val groupId: Output<String>? = null,
    public val privateLinkResourceId: Output<String>? = null,
    public val requestMessage: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val resourceName: Output<String>? = null,
    public val sharedPrivateLinkResourceName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResourceArgs> {
    override fun toJava(): com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResourceArgs =
        com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResourceArgs.builder()
            .groupId(groupId?.applyValue({ args0 -> args0 }))
            .privateLinkResourceId(privateLinkResourceId?.applyValue({ args0 -> args0 }))
            .requestMessage(requestMessage?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .resourceName(resourceName?.applyValue({ args0 -> args0 }))
            .sharedPrivateLinkResourceName(
                sharedPrivateLinkResourceName?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [WebPubSubSharedPrivateLinkResourceArgs].
 */
@PulumiTagMarker
public class WebPubSubSharedPrivateLinkResourceArgsBuilder internal constructor() {
    private var groupId: Output<String>? = null

    private var privateLinkResourceId: Output<String>? = null

    private var requestMessage: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var resourceName: Output<String>? = null

    private var sharedPrivateLinkResourceName: Output<String>? = null

    /**
     * @param value The group id from the provider of resource the shared private link resource is for
     */
    @JvmName("ahvijqriacldnjue")
    public suspend fun groupId(`value`: Output<String>) {
        this.groupId = value
    }

    /**
     * @param value The resource id of the resource the shared private link resource is for
     */
    @JvmName("gvxtrxkmiwknwgjr")
    public suspend fun privateLinkResourceId(`value`: Output<String>) {
        this.privateLinkResourceId = value
    }

    /**
     * @param value The request message for requesting approval of the shared private link resource
     */
    @JvmName("yctkofasvppdqakm")
    public suspend fun requestMessage(`value`: Output<String>) {
        this.requestMessage = value
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("ebjstdautoqrltqe")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the resource.
     */
    @JvmName("tqutfuxkxowslswk")
    public suspend fun resourceName(`value`: Output<String>) {
        this.resourceName = value
    }

    /**
     * @param value The name of the shared private link resource
     */
    @JvmName("wdtviohxucqrarwt")
    public suspend fun sharedPrivateLinkResourceName(`value`: Output<String>) {
        this.sharedPrivateLinkResourceName = value
    }

    /**
     * @param value The group id from the provider of resource the shared private link resource is for
     */
    @JvmName("kecmwmwhmweorgjn")
    public suspend fun groupId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupId = mapped
    }

    /**
     * @param value The resource id of the resource the shared private link resource is for
     */
    @JvmName("nhlgtieknfqetswn")
    public suspend fun privateLinkResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateLinkResourceId = mapped
    }

    /**
     * @param value The request message for requesting approval of the shared private link resource
     */
    @JvmName("ugxkcqtbjilpvhku")
    public suspend fun requestMessage(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requestMessage = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("ixbnfiqvqrelscla")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the resource.
     */
    @JvmName("kcahjtkyqwrjurnk")
    public suspend fun resourceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceName = mapped
    }

    /**
     * @param value The name of the shared private link resource
     */
    @JvmName("ohhvqlmixehcavpe")
    public suspend fun sharedPrivateLinkResourceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sharedPrivateLinkResourceName = mapped
    }

    internal fun build(): WebPubSubSharedPrivateLinkResourceArgs =
        WebPubSubSharedPrivateLinkResourceArgs(
            groupId = groupId,
            privateLinkResourceId = privateLinkResourceId,
            requestMessage = requestMessage,
            resourceGroupName = resourceGroupName,
            resourceName = resourceName,
            sharedPrivateLinkResourceName = sharedPrivateLinkResourceName,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/webpubsub/kotlin/WebPubSubSharedPrivateLinkResourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.webpubsub.kotlin

import com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResourceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes a Shared Private Link Resource
 * Azure REST API version: 2023-02-01. Prior API version in Azure Native 1.x: 2021-04-01-preview.
 * Other available API versions: 2023-03-01-preview, 2023-06-01-preview, 2023-08-01-preview.
 * ## Example Usage
 * ### WebPubSubSharedPrivateLinkResources_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var webPubSubSharedPrivateLinkResource = new AzureNative.WebPubSub.WebPubSubSharedPrivateLinkResource("webPubSubSharedPrivateLinkResource", new()
 *     {
 *         GroupId = "sites",
 *         PrivateLinkResourceId = "/subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/myResourceGroup/providers/Microsoft.Web/sites/myWebApp",
 *         RequestMessage = "Please approve",
 *         ResourceGroupName = "myResourceGroup",
 *         ResourceName = "myWebPubSubService",
 *         SharedPrivateLinkResourceName = "upstream",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/webpubsub/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := webpubsub.NewWebPubSubSharedPrivateLinkResource(ctx, "webPubSubSharedPrivateLinkResource", &webpubsub.WebPubSubSharedPrivateLinkResourceArgs{
 * 			GroupId:                       pulumi.String("sites"),
 * 			PrivateLinkResourceId:         pulumi.String("/subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/myResourceGroup/providers/Microsoft.Web/sites/myWebApp"),
 * 			RequestMessage:                pulumi.String("Please approve"),
 * 			ResourceGroupName:             pulumi.String("myResourceGroup"),
 * 			ResourceName:                  pulumi.String("myWebPubSubService"),
 * 			SharedPrivateLinkResourceName: pulumi.String("upstream"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResource;
 * import com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResourceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var webPubSubSharedPrivateLinkResource = new WebPubSubSharedPrivateLinkResource("webPubSubSharedPrivateLinkResource", WebPubSubSharedPrivateLinkResourceArgs.builder()
 *             .groupId("sites")
 *             .privateLinkResourceId("/subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/myResourceGroup/providers/Microsoft.Web/sites/myWebApp")
 *             .requestMessage("Please approve")
 *             .resourceGroupName("myResourceGroup")
 *             .resourceName("myWebPubSubService")
 *             .sharedPrivateLinkResourceName("upstream")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:webpubsub:WebPubSubSharedPrivateLinkResource upstream /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.SignalRService/webPubSub/{resourceName}/sharedPrivateLinkResources/{sharedPrivateLinkResourceName}
 * ```
 * @property groupId The group id from the provider of resource the shared private link resource is for
 * @property privateLinkResourceId The resource id of the resource the shared private link resource is for
 * @property requestMessage The request message for requesting approval of the shared private link resource
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property resourceName The name of the resource.
 * @property sharedPrivateLinkResourceName The name of the shared private link resource
 */
public data class WebPubSubSharedPrivateLinkResourceArgs(
    public val groupId: Output<String>? = null,
    public val privateLinkResourceId: Output<String>? = null,
    public val requestMessage: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val resourceName: Output<String>? = null,
    public val sharedPrivateLinkResourceName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResourceArgs> {
    override fun toJava(): com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResourceArgs =
        com.pulumi.azurenative.webpubsub.WebPubSubSharedPrivateLinkResourceArgs.builder()
            .groupId(groupId?.applyValue({ args0 -> args0 }))
            .privateLinkResourceId(privateLinkResourceId?.applyValue({ args0 -> args0 }))
            .requestMessage(requestMessage?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .resourceName(resourceName?.applyValue({ args0 -> args0 }))
            .sharedPrivateLinkResourceName(
                sharedPrivateLinkResourceName?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [WebPubSubSharedPrivateLinkResourceArgs].
 */
@PulumiTagMarker
public class WebPubSubSharedPrivateLinkResourceArgsBuilder internal constructor() {
    private var groupId: Output<String>? = null

    private var privateLinkResourceId: Output<String>? = null

    private var requestMessage: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var resourceName: Output<String>? = null

    private var sharedPrivateLinkResourceName: Output<String>? = null

    /**
     * @param value The group id from the provider of resource the shared private link resource is for
     */
    @JvmName("tmwbbbndwybbvnmu")
    public suspend fun groupId(`value`: Output<String>) {
        this.groupId = value
    }

    /**
     * @param value The resource id of the resource the shared private link resource is for
     */
    @JvmName("akxpogpltfevibgh")
    public suspend fun privateLinkResourceId(`value`: Output<String>) {
        this.privateLinkResourceId = value
    }

    /**
     * @param value The request message for requesting approval of the shared private link resource
     */
    @JvmName("npkgsjfsyobcdwux")
    public suspend fun requestMessage(`value`: Output<String>) {
        this.requestMessage = value
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("mdhdlkscbqflwqfs")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the resource.
     */
    @JvmName("rgvfkqibulnwfbij")
    public suspend fun resourceName(`value`: Output<String>) {
        this.resourceName = value
    }

    /**
     * @param value The name of the shared private link resource
     */
    @JvmName("rwukqgeyjaenjntb")
    public suspend fun sharedPrivateLinkResourceName(`value`: Output<String>) {
        this.sharedPrivateLinkResourceName = value
    }

    /**
     * @param value The group id from the provider of resource the shared private link resource is for
     */
    @JvmName("xpkoisifsulifoir")
    public suspend fun groupId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupId = mapped
    }

    /**
     * @param value The resource id of the resource the shared private link resource is for
     */
    @JvmName("octvsqcpopxavacs")
    public suspend fun privateLinkResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateLinkResourceId = mapped
    }

    /**
     * @param value The request message for requesting approval of the shared private link resource
     */
    @JvmName("cjfldplidbopeliw")
    public suspend fun requestMessage(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requestMessage = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("srabybcqigdpqmoj")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the resource.
     */
    @JvmName("coifptjtmcwohrdx")
    public suspend fun resourceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceName = mapped
    }

    /**
     * @param value The name of the shared private link resource
     */
    @JvmName("eodemjqdeeefipmm")
    public suspend fun sharedPrivateLinkResourceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sharedPrivateLinkResourceName = mapped
    }

    internal fun build(): WebPubSubSharedPrivateLinkResourceArgs =
        WebPubSubSharedPrivateLinkResourceArgs(
            groupId = groupId,
            privateLinkResourceId = privateLinkResourceId,
            requestMessage = requestMessage,
            resourceGroupName = resourceGroupName,
            resourceName = resourceName,
            sharedPrivateLinkResourceName = sharedPrivateLinkResourceName,
        )
}
